==> dokuwiki-2011.05.25a.tgz: dokuwiki/lib/plugins/plugin/lang/pt-br/lang.php <==
<?php
/**
 * Portuguese language file
 *
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Lucien Raven <lucienraven@yahoo.com.br>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Flávio Veras <flaviove@gmail.com>
 * @author Jeferson Propheta <jeferson.propheta@gmail.com>
 * @author jair.henrique@gmail.com
 * @author Luis Dantas <luis@dantas.com>
 * @author Frederico Guimarães <frederico@teia.bio.br>
 * @author Jair Henrique <jair.henrique@gmail.com>
 * @author Luis Dantas <luisdantas@gmail.com>
 * @author Sergio Motta sergio@cisne.com.br
 * @author Isaias Masiero Filho <masiero@masiero.org>
 */
$lang['menu']                  = 'Gerenciar Plug-ins';
$lang['download']              = 'Baixar e instalar um novo plug-in';
$lang['manage']                = 'Plug-ins instalados';
$lang['btn_info']              = 'informações';
$lang['btn_update']            = 'atualizar';
$lang['btn_delete']            = 'excluir';
$lang['btn_settings']          = 'configurações';
$lang['btn_download']          = 'Baixar';
$lang['btn_enable']            = 'Salvar';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalação:';
$lang['lastupdate']            = 'Última atualização:';
$lang['source']                = 'Fonte:';
$lang['unknown']               = 'desconhecida';
$lang['updating']              = 'Atualizando...';
$lang['updated']               = 'O plug-in %s foi atualizado com sucesso';
$lang['updates']               = 'Os seguintes plug-ins foram atualizados com sucesso';
$lang['update_none']           = 'Não foi encontrada nenhuma atualização.';
$lang['deleting']              = 'Excluindo...';
$lang['deleted']               = 'O plug-in %s foi excluído.';
$lang['downloading']           = 'Baixando...';
$lang['downloaded']            = 'O plug-in %s foi instalado com sucesso';
$lang['downloads']             = 'Os seguintes plug-ins foram instalados com sucesso:';
$lang['download_none']         = 'O plug-in não foi encontrado ou então ocorreu um problema desconhecido durante a transferência e instalação.';
$lang['plugin']                = 'Plug-in:';
$lang['components']            = 'Componentes';
$lang['noinfo']                = 'Esse plug-in não retornou nenhuma informação. Ele pode ser inválido.';
$lang['name']                  = 'Nome:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descrição:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Ocorreu um erro desconhecido.';
$lang['error_download']        = 'Não foi possível baixar o arquivo de plug-in: %s';
$lang['error_badurl']          = 'Suspeita de URL mal formatada - não foi possível determinar o nome do arquivo a partir da URL';
$lang['error_dircreate']       = 'Não foi possível criar a pasta temporária para receber a transferência';
$lang['error_decompress']      = 'O gerenciador de plug-ins não conseguiu descompactar o arquivo transferido. Isso pode ser resultado de: uma corrupção do arquivo durante a transferência, nesse caso, você deve tentar novamente; ou o formato da compactação pode ser desconhecido, nesse caso você deve transferir e instalar o plug-in manualmente.';
$lang['error_copy']            = 'Ocorreu um erro de cópia de arquivo na tentativa de instalar o plug-in <em>%s</em>: o disco pode estar cheio ou as permissões de acesso ao arquivo podem estar erradas. Isso pode resultar em um plug-in parcialmente instalado e tornar o seu wiki instável.';
$lang['error_delete']          = 'Ocorreu um erro na tentativa de excluir o plug-in <em>%s</em>. A causa mais provável é a permissão de acesso insuficiente ao diretório ou ao arquivo.';
$lang['enabled']               = 'O plug-in %s foi habilitado.';
$lang['notenabled']            = 'Não foi possível habilitar o plug-in %s. Verifique as permissões de acesso.';
$lang['disabled']              = 'O plug-in %s foi desabilitado.';
$lang['notdisabled']           = 'Não foi possível desabilitar o plug-in %s. Verifique as permissões de acesso.';
$lang['packageinstalled']      = 'O pacote do plugin (%d plugin%s: %s) foi instalado com sucesso.';

==> dokuwiki-2012.01.25b.tgz: dokuwiki/lib/plugins/plugin/lang/pt-br/lang.php <==
<?php
/**
 * Portuguese language file
 *
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Lucien Raven <lucienraven@yahoo.com.br>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Flávio Veras <flaviove@gmail.com>
 * @author Jeferson Propheta <jeferson.propheta@gmail.com>
 * @author jair.henrique@gmail.com
 * @author Luis Dantas <luis@dantas.com>
 * @author Frederico Guimarães <frederico@teia.bio.br>
 * @author Jair Henrique <jair.henrique@gmail.com>
 * @author Luis Dantas <luisdantas@gmail.com>
 * @author Sergio Motta sergio@cisne.com.br
 * @author Isaias Masiero Filho <masiero@masiero.org>
 * @author Balaco Baco <balacobaco@imap.cc>
 */
$lang['menu']                  = 'Gerenciar Plug-ins';
$lang['download']              = 'Baixar e instalar um novo plug-in';
$lang['manage']                = 'Plug-ins instalados';
$lang['btn_info']              = 'informações';
$lang['btn_update']            = 'atualizar';
$lang['btn_delete']            = 'excluir';
$lang['btn_settings']          = 'configurações';
$lang['btn_download']          = 'Baixar';
$lang['btn_enable']            = 'Salvar';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalação:';
$lang['lastupdate']            = 'Última atualização:';
$lang['source']                = 'Fonte:';
$lang['unknown']               = 'desconhecida';
$lang['updating']              = 'Atualizando...';
$lang['updated']               = 'O plug-in %s foi atualizado com sucesso';
$lang['updates']               = 'Os seguintes plug-ins foram atualizados com sucesso';
$lang['update_none']           = 'Não foi encontrada nenhuma atualização.';
$lang['deleting']              = 'Excluindo...';
$lang['deleted']               = 'O plug-in %s foi excluído.';
$lang['downloading']           = 'Baixando...';
$lang['downloaded']            = 'O plug-in %s foi instalado com sucesso';
$lang['downloads']             = 'Os seguintes plug-ins foram instalados com sucesso:';
$lang['download_none']         = 'O plug-in não foi encontrado ou então ocorreu um problema desconhecido durante a transferência e instalação.';
$lang['plugin']                = 'Plug-in:';
$lang['components']            = 'Componentes';
$lang['noinfo']                = 'Esse plug-in não retornou nenhuma informação. Ele pode ser inválido.';
$lang['name']                  = 'Nome:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descrição:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Ocorreu um erro desconhecido.';
$lang['error_download']        = 'Não foi possível baixar o arquivo de plug-in: %s';
$lang['error_badurl']          = 'Suspeita de URL mal formatada - não foi possível determinar o nome do arquivo a partir da URL';
$lang['error_dircreate']       = 'Não foi possível criar a pasta temporária para receber a transferência';
$lang['error_decompress']      = 'O gerenciador de plug-ins não conseguiu descompactar o arquivo transferido. Isso pode ser resultado de: uma corrupção do arquivo durante a transferência, nesse caso, você deve tentar novamente; ou o formato da compactação pode ser desconhecido, nesse caso você deve transferir e instalar o plug-in manualmente.';
$lang['error_copy']            = 'Ocorreu um erro de cópia de arquivo na tentativa de instalar o plug-in <em>%s</em>: o disco pode estar cheio ou as permissões de acesso ao arquivo podem estar erradas. Isso pode resultar em um plug-in parcialmente instalado e tornar o seu wiki instável.';
$lang['error_delete']          = 'Ocorreu um erro na tentativa de excluir o plug-in <em>%s</em>. A causa mais provável é a permissão de acesso insuficiente ao diretório ou ao arquivo.';
$lang['enabled']               = 'O plug-in %s foi habilitado.';
$lang['notenabled']            = 'Não foi possível habilitar o plug-in %s. Verifique as permissões de acesso.';
$lang['disabled']              = 'O plug-in %s foi desabilitado.';
$lang['notdisabled']           = 'Não foi possível desabilitar o plug-in %s. Verifique as permissões de acesso.';
$lang['packageinstalled']      = 'O pacote do plugin (%d plugin(s): %s) foi instalado com sucesso.';
